@@ -1,7 +1,9 @@
-from .base_model_manager import to_dataframe, BaseModelDataFrameManager
+from pandas_orm.sqlalchemy.model_dataframe_manager import ModelDataFrameManager
+from pandas_orm.sqlalchemy.query import to_dataframe
+from pandas_orm.sqlalchemy.dataframe import DataFrame
 
 
-class ModelManager(BaseModelDataFrameManager):
+class ModelManager(ModelDataFrameManager):
 
     def __init__(self, model, *args, **kwargs):
         super(__class__, self).__init__(*args, **kwargs)
@@ -22,7 +24,7 @@ class ModelManager(BaseModelDataFrameManager):
                 )
             return prepared_statement
 
-    def bulk_save(self, records, unique_fields=None, update_fields=None, returning_id=False):
+    def bulk_save(self, records, unique_fields=None, update_fields=None, returning_id=False)->DataFrame:
         return self._bulk_save(
             records=records,
             model=self.model,
